@@ -3,20 +3,7 @@
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+* SPDX-License-Identifier: GPL-2.0+ */
 
 #ifndef __WTAP_H__
 #define __WTAP_H__
@@ -25,8 +12,13 @@
 #include <time.h>
 #include <wsutil/buffer.h>
 #include <wsutil/nstime.h>
+#include <wsutil/inet_addr.h>
 #include "wtap_opttypes.h"
 #include "ws_symbol_export.h"
+#include "ws_attributes.h"
+#ifdef HAVE_PLUGINS
+#include "wsutil/plugins.h"
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -269,6 +261,24 @@ extern "C" {
 #define WTAP_ENCAP_GFP_F                        179
 #define WTAP_ENCAP_IP_OVER_IB_PCAP              180
 #define WTAP_ENCAP_JUNIPER_VN                   181
+#define WTAP_ENCAP_USB_DARWIN                   182
+#define WTAP_ENCAP_LORATAP                      183
+#define WTAP_ENCAP_3MB_ETHERNET                 184
+#define WTAP_ENCAP_VSOCK                        185
+#define WTAP_ENCAP_NORDIC_BLE                   186
+#define WTAP_ENCAP_NETMON_NET_NETEVENT          187
+#define WTAP_ENCAP_NETMON_HEADER                188
+#define WTAP_ENCAP_NETMON_NET_FILTER            189
+#define WTAP_ENCAP_NETMON_NETWORK_INFO_EX       190
+#define WTAP_ENCAP_MA_WFP_CAPTURE_V4            191
+#define WTAP_ENCAP_MA_WFP_CAPTURE_V6            192
+#define WTAP_ENCAP_MA_WFP_CAPTURE_2V4           193
+#define WTAP_ENCAP_MA_WFP_CAPTURE_2V6           194
+#define WTAP_ENCAP_MA_WFP_CAPTURE_AUTH_V4       195
+#define WTAP_ENCAP_MA_WFP_CAPTURE_AUTH_V6       196
+#define WTAP_ENCAP_JUNIPER_ST                   197
+#define WTAP_ENCAP_ETHERNET_MPACKET             198
+
 /* After adding new item here, please also add new item to encap_table_base array */
 
 #define WTAP_NUM_ENCAP_TYPES                    wtap_get_num_encap_types()
@@ -374,11 +384,20 @@ extern "C" {
 /* if you add to the above, update wtap_tsprec_string() */
 
 /*
- * Maximum packet size we'll support.
- * 262144 is the largest snapshot length that libpcap supports, so we
- * use that.
+ * We support one maximum packet size for most link-layer header types
+ * and another for D-Bus, because the maximum packet size for D-Bus
+ * is 128MB, as per
+ *
+ *    https://dbus.freedesktop.org/doc/dbus-specification.html#message-protocol-messages
+ *
+ * and that's a lot bigger than the 256KB that we use elsewhere.
+ *
+ * We don't want to write out files that specify a maximum packet size of
+ * 128MB if we don't have to, as software reading those files might
+ * allocate a buffer much larger than necessary, wasting memory.
  */
-#define WTAP_MAX_PACKET_SIZE    262144
+#define WTAP_MAX_PACKET_SIZE_STANDARD    262144
+#define WTAP_MAX_PACKET_SIZE_DBUS        (128*1024*1024)
 
 /*
  * "Pseudo-headers" are used to supply to the clients of wiretap
@@ -759,20 +778,22 @@ struct ieee_802_11ad {
     guint8   mcs;            /* MCS index */
 };
 
+union ieee_802_11_phy_info {
+    struct ieee_802_11_fhss info_11_fhss;
+    struct ieee_802_11b info_11b;
+    struct ieee_802_11a info_11a;
+    struct ieee_802_11g info_11g;
+    struct ieee_802_11n info_11n;
+    struct ieee_802_11ac info_11ac;
+    struct ieee_802_11ad info_11ad;
+};
+
 struct ieee_802_11_phdr {
     gint     fcs_len;        /* Number of bytes of FCS - -1 means "unknown" */
     gboolean decrypted;      /* TRUE if frame is decrypted even if "protected" bit is set */
     gboolean datapad;        /* TRUE if frame has padding between 802.11 header and payload */
     guint    phy;            /* PHY type */
-    union {
-        struct ieee_802_11_fhss info_11_fhss;
-        struct ieee_802_11b info_11b;
-        struct ieee_802_11a info_11a;
-        struct ieee_802_11g info_11g;
-        struct ieee_802_11n info_11n;
-        struct ieee_802_11ac info_11ac;
-        struct ieee_802_11ad info_11ad;
-    } phy_info;
+    union ieee_802_11_phy_info phy_info;
 
     /* Which of this information is present? */
     guint    has_channel:1;
@@ -944,7 +965,7 @@ struct erf_ehdr {
  * (Multichannel or Ethernet)
  */
 
-#define MAX_ERF_EHDR 8
+#define MAX_ERF_EHDR 16
 
 struct wtap_erf_eth_hdr {
     guint8 offset;
@@ -1130,6 +1151,21 @@ struct sysdig_event_phdr {
     /* ... Event ... */
 };
 
+/* Packet "pseudo-header" information for header data from NetMon files. */
+
+struct netmon_phdr {
+    guint32 titleLength;    /* Number of bytes in the comment title */
+    guint8* title;          /* Comment title */
+    guint32 descLength;     /* Number of bytes in the comment description */
+    guint8* description;    /* Comment description */
+    guint sub_encap;        /* "Real" encap value for the record that will be used once pseudo header data is display */
+    union sub_wtap_pseudo_header {
+        struct eth_phdr     eth;
+        struct atm_phdr     atm;
+        struct ieee_802_11_phdr ieee_802_11;
+    } subheader;
+};
+
 /* Pseudo-header for file-type-specific records */
 struct ft_specific_record_phdr {
     guint record_type;    /* the type of record this is */
@@ -1162,6 +1198,7 @@ union wtap_pseudo_header {
     struct llcp_phdr    llcp;
     struct logcat_phdr  logcat;
     struct sysdig_event_phdr sysdig_event;
+    struct netmon_phdr  netmon;
     struct ft_specific_record_phdr ftsrec;
 };
 
@@ -1173,7 +1210,7 @@ union wtap_pseudo_header {
  *
  * For file-type-specific records, the "ftsrec" field of the pseudo-header
  * contains a file-type-specific subtype value, such as a block type for
- * a pcap-ng file.
+ * a pcapng file.
  *
  * An "event" is an indication that something happened during the capture
  * process, such as a status transition of some sort on the network.
@@ -1184,7 +1221,7 @@ union wtap_pseudo_header {
  * packets are.
  *
  * A "report" supplies information not corresponding to an event;
- * for example, a pcap-ng Interface Statistics Block would be a report,
+ * for example, a pcapng Interface Statistics Block would be a report,
  * as it doesn't correspond to something happening on the network.
  * They may have a time stamp, and should be dissected and displayed
  * just as packets are.
@@ -1200,6 +1237,22 @@ union wtap_pseudo_header {
  * information in them stored somewhere, and used somewhere, whether
  * it's just used when saving the file in its native format or also
  * used to parse *other* file-type-specific records.
+ *
+ * These would be similar to, for example, pcapng Interface Description
+ * Blocks, for which the position within the file is significant only
+ * in that an IDB for an interface must appear before any packets from
+ * the interface; the fact that an IDB appears at some point doesn't
+ * necessarily mean something happened in the capture at that point.
+ * Name Resolution Blocks are another example of such a record.
+ *
+ * (XXX - if you want to have a record that says "this interface first
+ * showed up at this time", that needs to be a separate record type
+ * from the IDB.  We *could* add a "New Interface Description Block",
+ * with a time stamp, for that purpose, but we'd *still* have to
+ * provide IDBs for those interfaces, for compatibility with programs
+ * that don't know about the NIDB.  An ISB with only an isb_starttime
+ * option would suffice for this purpose, so nothing needs to be
+ * added to pcapng for this.)
  */
 #define REC_TYPE_PACKET               0    /**< packet */
 #define REC_TYPE_FT_SPECIFIC_EVENT    1    /**< file-type-specific event */
@@ -1218,6 +1271,8 @@ struct wtap_pkthdr {
     guint32   interface_id;     /* identifier of the interface. */
                                 /* options */
     gchar     *opt_comment;     /* NULL if not available */
+    gboolean  has_comment_changed; /* TRUE if the comment has been changed. Currently only valid while dumping. */
+
     guint64   drop_count;       /* number of packets lost (by the interface and the
                                    operating system) between this packet and the preceding one. */
     guint32   pack_flags;       /* XXX - 0 for now (any value for "we don't have it"?) */
@@ -1283,7 +1338,6 @@ typedef struct wtapng_if_descr_mandatory_s {
     guint64                time_units_per_second;
     int                    tsprecision;           /**< WTAP_TSPREC_ value for this interface */
 
-    guint16                link_type;
     guint32                snap_len;
 
     guint8                 num_stat_entries;
@@ -1301,7 +1355,7 @@ typedef struct wtapng_if_descr_filter_s {
 } wtapng_if_descr_filter_t;
 
 /**
- * Holds the required data for pcap-ng Interface Statistics Block (ISB).
+ * Holds the required data for pcapng Interface Statistics Block (ISB).
  */
 typedef struct wtapng_if_stats_mandatory_s {
     guint32  interface_id;
@@ -1316,14 +1370,14 @@ typedef struct wtapng_if_stats_mandatory_s {
 typedef struct hashipv4 {
     guint             addr;
     guint8            flags;          /* B0 dummy_entry, B1 resolve, B2 If the address is used in the trace */
-    gchar             ip[16];
+    gchar             ip[WS_INET_ADDRSTRLEN];
     gchar             name[MAXNAMELEN];
 } hashipv4_t;
 
 typedef struct hashipv6 {
     guint8            addr[16];
     guint8            flags;          /* B0 dummy_entry, B1 resolve, B2 If the address is used in the trace */
-    gchar             ip6[46];
+    gchar             ip6[WS_INET6_ADDRSTRLEN];
     gchar             name[MAXNAMELEN];
 } hashipv6_t;
 
@@ -1359,23 +1413,29 @@ typedef struct wtap_wslua_file_info {
 } wtap_wslua_file_info_t;
 
 /*
- * For registering extensions used for capture file formats.
+ * For registering extensions used for file formats.
  *
  * These items are used in dialogs for opening files, so that
  * the user can ask to see all capture files (as identified
  * by file extension) or particular types of capture files.
  *
- * Each file type has a description and a list of extensions the file
- * might have.  Some file types aren't real file types, they're
- * just generic types, such as "text file" or "XML file", that can
- * be used for, among other things, captures we can read, or for
- * extensions such as ".cap" that were unimaginatively chosen by
- * several different sniffers for their file formats.
+ * Each file type has a description, a flag indicating whether it's
+ * a capture file or just some file whose contents we can dissect,
+ * and a list of extensions the file might have.
+ *
+ * Some file types aren't real file types, they're just generic types,
+ * such as "text file" or "XML file", that can be used for, among other
+ * things, captures we can read, or for extensions such as ".cap" that
+ * were unimaginatively chosen by several different sniffers for their
+ * file formats.
  */
 struct file_extension_info {
     /* the file type name */
     const char *name;
 
+    /* TRUE if this is a capture file type */
+    gboolean is_capture_file;
+
     /* a semicolon-separated list of file extensions used for this type */
     const char *extensions;
 };
@@ -1419,7 +1479,7 @@ typedef wtap_open_return_val (*wtap_open_routine_t)(struct wtap*, int *,
 /*
  * Some file formats have defined magic numbers at fixed offsets from
  * the beginning of the file; those routines should return 1 if and
- * only if the file has the magic number at that offset.  (pcap-ng
+ * only if the file has the magic number at that offset.  (pcapng
  * is a bit of a special case, as it has both the Section Header Block
  * type field and its byte-order magic field; it checks for both.)
  * Those file formats do not require a file name extension in order
@@ -1442,6 +1502,8 @@ typedef enum {
 
 WS_DLL_PUBLIC void init_open_routines(void);
 
+void cleanup_open_routines(void);
+
 struct open_info {
     const char *name;
     wtap_open_type type;
@@ -1503,6 +1565,14 @@ struct file_type_subtype_info {
 
 #define WTAP_TYPE_AUTO 0
 
+/**
+ * @brief Initialize the Wiretap library.
+ *
+ * @param load_wiretap_plugins Load Wiretap plugins when initializing library.
+*/
+WS_DLL_PUBLIC
+void wtap_init(gboolean load_wiretap_plugins);
+
 /** On failure, "wtap_open_offline()" returns NULL, and puts into the
  * "int" pointed to by its second argument:
  *
@@ -1707,9 +1777,11 @@ void wtap_fdclose(wtap *wth);
 WS_DLL_PUBLIC
 gboolean wtap_fdreopen(wtap *wth, const char *filename, int *err);
 
-/*** close the current file ***/
+/** Close only the sequential side, freeing up memory it uses. */
 WS_DLL_PUBLIC
 void wtap_sequential_close(wtap *wth);
+
+/** Closes any open file handles and frees the memory associated with wth. */
 WS_DLL_PUBLIC
 void wtap_close(wtap *wth);
 
@@ -1867,9 +1939,18 @@ WS_DLL_PUBLIC
 void wtap_set_bytes_dumped(wtap_dumper *wdh, gint64 bytes_dumped);
 struct addrinfo;
 WS_DLL_PUBLIC
+gboolean wtap_addrinfo_list_empty(addrinfo_lists_t *addrinfo_lists);
+WS_DLL_PUBLIC
 gboolean wtap_dump_set_addrinfo_list(wtap_dumper *wdh, addrinfo_lists_t *addrinfo_lists);
 WS_DLL_PUBLIC
-gboolean wtap_dump_close(wtap_dumper *, int *);
+gboolean wtap_dump_get_needs_reload(wtap_dumper *wdh);
+
+/**
+ * Closes open file handles and frees memory associated with wdh. Note that
+ * shb_hdr, idb_inf and nrb_hdr are not freed by this routine.
+ */
+WS_DLL_PUBLIC
+gboolean wtap_dump_close(wtap_dumper *wdh, int *err);
 
 /**
  * Return TRUE if we can write a file out with the given GArray of file
@@ -1897,7 +1978,7 @@ int wtap_short_string_to_file_type_subtype(const char *short_name);
 
 /*** various file extension functions ***/
 WS_DLL_PUBLIC
-GSList *wtap_get_all_file_extensions_list(void);
+GSList *wtap_get_all_capture_file_extensions_list(void);
 WS_DLL_PUBLIC
 const char *wtap_default_file_extension(int filetype);
 WS_DLL_PUBLIC
@@ -1934,12 +2015,17 @@ GSList *wtap_get_file_extension_type_extensions(guint extension_type);
 
 /*** dynamically register new file types and encapsulations ***/
 WS_DLL_PUBLIC
-void wtap_register_plugin_types(void);
-WS_DLL_PUBLIC
-void register_all_wiretap_modules(void);
-WS_DLL_PUBLIC
 void wtap_register_file_type_extension(const struct file_extension_info *ei);
 
+#ifdef HAVE_PLUGINS
+typedef struct {
+	void (*register_wtap_module)(void);  /* routine to call to register a wiretap module */
+} wtap_plugin;
+
+WS_DLL_PUBLIC
+void wtap_register_plugin(const wtap_plugin *plug);
+#endif
+
 WS_DLL_PUBLIC
 void wtap_register_open_info(struct open_info *oi, const gboolean first_routine);
 WS_DLL_PUBLIC
@@ -1957,6 +2043,9 @@ void wtap_deregister_file_type_subtype(const int file_type_subtype);
 WS_DLL_PUBLIC
 int wtap_register_encap_type(const char* name, const char* short_name);
 
+/*** Cleanup the interal library structures */
+WS_DLL_PUBLIC
+void wtap_cleanup(void);
 
 /**
  * Wiretap error codes.
@@ -2040,6 +2129,9 @@ int wtap_register_encap_type(const char* name, const char* short_name);
 #define WTAP_ERR_UNWRITABLE_REC_DATA          -25
     /** Something in the record data can't be written to that file type */
 
+#define WTAP_ERR_DECOMPRESSION_NOT_SUPPORTED  -26
+    /** We don't support decompressing that type of compressed file */
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
